@@ -100,7 +100,8 @@ QAction *CompressFileItemAction::createAction(const QIcon &icon, QWidget *parent
     QAction *action = new QAction(icon, name, parent);
 
     connect(action, &QAction::triggered, this, [fileExtension, urls, name, parent, this]() {
-        auto *addToArchiveJob = new AddToArchive(parent);
+        // Don't pass a parent to the job, otherwise it will be killed if dolphin gets closed.
+        auto *addToArchiveJob = new AddToArchive(nullptr);
         addToArchiveJob->setImmediateProgressReporting(true);
         addToArchiveJob->setChangeToFirstPath(true);
         for (const QUrl &url : urls) {
@@ -109,7 +110,7 @@ QAction *CompressFileItemAction::createAction(const QIcon &icon, QWidget *parent
         if (!fileExtension.isEmpty()) {
             addToArchiveJob->setAutoFilenameSuffix(fileExtension);
         } else {
-            if (!addToArchiveJob->showAddDialog()) {
+            if (!addToArchiveJob->showAddDialog(parent)) {
                 delete addToArchiveJob;
                 return;
             }
@@ -121,6 +122,7 @@ QAction *CompressFileItemAction::createAction(const QIcon &icon, QWidget *parent
             } else if (!addToArchiveJob->errorString().isEmpty()) {
                 Q_EMIT error(addToArchiveJob->errorString());
             }
+            addToArchiveJob->deleteLater();
         });
     });
 
