@@ -1,23 +1,8 @@
 /*
- * ark -- archiver for the KDE project
- *
- * Copyright (C) 2009 Harald Hvaal <haraldhv (at@at) stud.ntnu.no>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- */
+    SPDX-FileCopyrightText: 2009 Harald Hvaal <haraldhv (at@at) stud.ntnu.no>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "extractHereDndPlugin.h"
 #include "ark_debug.h"
@@ -29,7 +14,6 @@
 
 #include <KFileItemListProperties>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KLocalizedString>
 
 K_PLUGIN_CLASS_WITH_JSON(ExtractHereDndPlugin, "ark_dndextract.json")
@@ -42,7 +26,7 @@ void ExtractHereDndPlugin::slotTriggered()
     batchJob->setAutoSubfolder(true);
     batchJob->setDestinationFolder(m_dest.toDisplayString(QUrl::PreferLocalFile));
     batchJob->setPreservePaths(true);
-    for (const QUrl& url : qAsConst(m_urls)) {
+    for (const QUrl& url : std::as_const(m_urls)) {
         batchJob->addInput(url);
     }
 
