@@ -926,7 +926,9 @@ void Part::slotCompleted()
         qCWarning(ARK) << "No entry listed by the plugin";
         displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "The archive is empty or Ark could not open its content."));
     } else if (m_model->rowCount() == 1 &&
-               m_model->archive()->mimeType().inherits(QStringLiteral("application/x-cd-image")) &&
+               // TODO: drop application/x-cd-image once all distributions ship shared-mime-info >= 2.3
+               (m_model->archive()->mimeType().inherits(QStringLiteral("application/x-cd-image")) ||
+                m_model->archive()->mimeType().inherits(QStringLiteral("application/vnd.efi.img"))) &&
                m_model->entryForIndex(m_model->index(0, 0))->fullPath() == QLatin1String("README.TXT")) {
         qCWarning(ARK) << "Detected ISO image with UDF filesystem";
         displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "Ark does not currently support ISO files with UDF filesystem."));
